@@ -35,6 +35,8 @@
 #define EXIT_SUCCESS 0
 #define EXIT_FAILURE 1
 
+int debugmode = 0;
+
 /* Daemonize. Source: http://www-theorie.physik.unizh.ch/~dpotter/howto/daemonize (public domain) */
 static void daemonize(void) {
 	pid_t pid, sid;
@@ -285,9 +287,13 @@ Window getCurrentWindow() {
 	Window* childWindows = NULL;
 	unsigned int childCount;
 
+
 	XClassHint* classHint = XAllocClassHint();
 
+	int i = 0;
 	while (1) {
+		i++;
+		if(i >= 5) return None;
 		if (currentWindow == ROOT) {
 			/* No top-level window available. Should never happen. */
 			XFree(classHint);
@@ -301,6 +307,10 @@ Window getCurrentWindow() {
 			if (childWindows != NULL)
 				XFree(childWindows);
 
+			if(currentWindow == parent) {
+				/* something wrong */
+				return currentWindow;
+			}
 			currentWindow = parent;
 		} else {
 			XFree(classHint);
@@ -909,6 +919,7 @@ int main(int argc, char **argv) {
 	for (i = 1; i < argc; i++) {
 		if (strcmp(argv[i], "--debug") == 0) {
 			doDaemonize = 0;
+			debugmode = 1;
 		} else if (strcmp(argv[i], "--wait") == 0) {
 			doWait = 1;
 		} else {
@@ -917,6 +928,8 @@ int main(int argc, char **argv) {
 
 	}
 
+
+
 	if (doDaemonize) {
 		daemonize();
 	}
